@@ -34,6 +34,9 @@ class Dns:
         self.domain_config.save(domain)
         return domain
 
+    def drop(self):
+        self.domain_config.remove()
+
     def add_service(self, name, protocol, type, port, url=None):
         self.port_mapper.add(port)
         new_service = Service(name, protocol, type, port, url)
