@@ -78,7 +78,7 @@ def get_insider(bin_path, config_path, logs_path):
 
     dns_service = dns.Dns(
         insider_config.get_redirect_api_url(),
-        insider_config.get_redirect_main_domain,
+        insider_config.get_redirect_main_domain(),
         domain_config,
         service_config,
         mapper)
