@@ -39,6 +39,8 @@ class TestCli(unittest.TestCase):
 
     def test_set_redirect_info(self):
 
+        call('cp {}/test_domain.json {}/test-config/domain.json'.format(test_dir, root_dir), shell=True)
+
         call('{} set_redirect_info domain1 http://api.domain1'.format(cmd), shell=True)
         parser = ConfigParser()
         parser.read('{}/test-config/insider.cfg'.format(root_dir))
@@ -46,6 +48,9 @@ class TestCli(unittest.TestCase):
         self.assertEquals(parser.get('redirect', 'domain'), 'domain1')
         self.assertEquals(parser.get('redirect', 'api_url'), 'http://api.domain1')
 
+        output = check_output('{} full_name'.format(cmd), shell=True)
+        self.assertTrue("\"device.domain.domain1\"" in output)
+
         call('{} set_redirect_info domain2 http://api.domain2'.format(cmd), shell=True)
         parser = ConfigParser()
         parser.read('{}/test-config/insider.cfg'.format(root_dir))
@@ -53,6 +58,9 @@ class TestCli(unittest.TestCase):
         self.assertEquals(parser.get('redirect', 'domain'), 'domain2')
         self.assertEquals(parser.get('redirect', 'api_url'), 'http://api.domain2')
 
+        output = check_output('{} full_name'.format(cmd), shell=True)
+        self.assertTrue("\"device.domain.domain2\"" in output)
+
     def test_acquire_domain(self):
 
         # TODO: Implement dummy web-server
